==> jei-1.19.4-fabric-13.1.0.8-sources.jar: mezz/jei/gui/input/GuiTextFieldFilter.java <==
package mezz.jei.gui.input;

import com.mojang.blaze3d.systems.RenderSystem;
import mezz.jei.common.gui.elements.DrawableNineSliceTexture;
import mezz.jei.common.gui.textures.Textures;
import mezz.jei.common.platform.IPlatformScreenHelper;
import mezz.jei.common.platform.Services;
import mezz.jei.common.util.ImmutableRect2i;
import mezz.jei.core.util.TextHistory;
import mezz.jei.gui.input.handlers.TextFieldInputHandler;
import net.minecraft.class_310;
import net.minecraft.class_339;
import net.minecraft.class_342;
import net.minecraft.class_437;
import net.minecraft.class_4587;
import net.minecraft.class_5244;
import org.jetbrains.annotations.Nullable;

import java.util.Optional;

public class GuiTextFieldFilter extends class_342 {
	private static final int maxSearchLength = 128;
	private static final TextHistory history = new TextHistory();

	private ImmutableRect2i area;
	private final DrawableNineSliceTexture background;
	private ImmutableRect2i backgroundBounds;

	private @Nullable class_339 previouslyFocusedWidget;

	public GuiTextFieldFilter(Textures textures) {
		// TODO narrator string
		super(class_310.method_1551().field_1772, 0, 0, 0, 0, class_5244.field_39003);

		method_1880(maxSearchLength);
		this.area = ImmutableRect2i.EMPTY;
		this.background = textures.getSearchBackground();
		this.backgroundBounds = ImmutableRect2i.EMPTY;
		method_1858(false);
	}

	public void updateBounds(ImmutableRect2i area) {
		this.backgroundBounds = area;
		method_46421(area.getX() + 4);
		method_46419(area.getY() + (area.getHeight() - 8) / 2);
		this.field_22758 = area.getWidth() - 12;
		this.field_22759 = area.getHeight();
		this.area = area;
	}

	@Override
	public void method_1852(String filterText) {
		if (!filterText.equals(method_1882())) {
			super.method_1852(filterText);
		}
	}

	public Optional<String> getHistory(TextHistory.Direction direction) {
		String currentText = method_1882();
		return history.get(direction, currentText);
	}

	@Override
	public boolean method_25405(double mouseX, double mouseY) {
		return area.contains(mouseX, mouseY);
	}

	public IUserInputHandler createInputHandler() {
		return new TextFieldInputHandler(this);
	}

	@Override
	public void method_25365(boolean keyboardFocus) {
		final boolean previousFocus = method_25370();
		super.method_25365(keyboardFocus);

		if (previousFocus != keyboardFocus) {
			class_310 minecraft = class_310.method_1551();
			if (keyboardFocus) {
				class_437 screen = minecraft.field_1755;
				if (screen != null) {
					if (screen.method_25399() instanceof class_339 widget) {
						IPlatformScreenHelper screenHelper = Services.PLATFORM.getScreenHelper();
						screenHelper.setFocused(widget, false);
						previouslyFocusedWidget = widget;
					}
					screen.method_25395(null);
				}
			} else {
				if (previouslyFocusedWidget != null) {
					class_437 screen = minecraft.field_1755;
					if (screen != null) {
						IPlatformScreenHelper screenHelper = Services.PLATFORM.getScreenHelper();
						screenHelper.setFocused(previouslyFocusedWidget, true);
						screen.method_25395(previouslyFocusedWidget);
					}
					previouslyFocusedWidget = null;
				}
			}

			String text = method_1882();
			history.add(text);
		}
	}

	@Override
	public void method_48579(class_4587 poseStack, int mouseX, int mouseY, float partialTicks) {
		if (this.method_1885()) {
			RenderSystem.setShaderColor(1, 1, 1, 1);
			background.draw(poseStack, this.backgroundBounds);
		}
		super.method_48579(poseStack, mouseX, mouseY, partialTicks);
	}
}

==> jei-1.20-fabric-14.0.0.4-sources.jar: mezz/jei/gui/input/GuiTextFieldFilter.java <==
package mezz.jei.gui.input;

import com.mojang.blaze3d.systems.RenderSystem;
import mezz.jei.common.gui.elements.DrawableNineSliceTexture;
import mezz.jei.common.gui.textures.Textures;
import mezz.jei.common.platform.IPlatformScreenHelper;
import mezz.jei.common.platform.Services;
import mezz.jei.common.util.ImmutableRect2i;
import mezz.jei.core.util.TextHistory;
import mezz.jei.gui.input.handlers.TextFieldInputHandler;
import net.minecraft.class_310;
import net.minecraft.class_332;
import net.minecraft.class_339;
import net.minecraft.class_342;
import net.minecraft.class_437;
import net.minecraft.class_5244;
import org.jetbrains.annotations.Nullable;

import java.util.Optional;

public class GuiTextFieldFilter extends class_342 {
	private static final int maxSearchLength = 128;
	private static final TextHistory history = new TextHistory();

	private ImmutableRect2i area;
	private final DrawableNineSliceTexture background;
	private ImmutableRect2i backgroundBounds;

	private @Nullable class_339 previouslyFocusedWidget;

	public GuiTextFieldFilter(Textures textures) {
		// TODO narrator string
		super(class_310.method_1551().field_1772, 0, 0, 0, 0, class_5244.field_39003);

		method_1880(maxSearchLength);
		this.area = ImmutableRect2i.EMPTY;
		this.background = textures.getSearchBackground();
		this.backgroundBounds = ImmutableRect2i.EMPTY;
		method_1858(false);
	}

	public void updateBounds(ImmutableRect2i area) {
		this.backgroundBounds = area;
		method_46421(area.getX() + 4);
		method_46419(area.getY() + (area.getHeight() - 8) / 2);
		this.field_22758 = area.getWidth() - 12;
		this.field_22759 = area.getHeight();
		this.area = area;
	}

	@Override
	public void method_1852(String filterText) {
		if (!filterText.equals(method_1882())) {
			super.method_1852(filterText);
		}
	}

	public Optional<String> getHistory(TextHistory.Direction direction) {
		String currentText = method_1882();
		return history.get(direction, currentText);
	}

	@Override
	public boolean method_25405(double mouseX, double mouseY) {
		return area.contains(mouseX, mouseY);
	}

	public IUserInputHandler createInputHandler() {
		return new TextFieldInputHandler(this);
	}

	@Override
	public void method_25365(boolean keyboardFocus) {
		final boolean previousFocus = method_25370();
		super.method_25365(keyboardFocus);

		if (previousFocus != keyboardFocus) {
			class_310 minecraft = class_310.method_1551();
			if (keyboardFocus) {
				class_437 screen = minecraft.field_1755;
				if (screen != null) {
					if (screen.method_25399() instanceof class_339 widget) {
						IPlatformScreenHelper screenHelper = Services.PLATFORM.getScreenHelper();
						screenHelper.setFocused(widget, false);
						previouslyFocusedWidget = widget;
					}
					screen.method_25395(null);
				}
			} else {
				if (previouslyFocusedWidget != null) {
					class_437 screen = minecraft.field_1755;
					if (screen != null) {
						IPlatformScreenHelper screenHelper = Services.PLATFORM.getScreenHelper();
						screenHelper.setFocused(previouslyFocusedWidget, true);
						screen.method_25395(previouslyFocusedWidget);
					}
					previouslyFocusedWidget = null;
				}
			}

			String text = method_1882();
			history.add(text);
		}
	}

	@Override
	public void method_48579(class_332 guiGraphics, int mouseX, int mouseY, float partialTicks) {
		if (this.method_1885()) {
			RenderSystem.setShaderColor(1, 1, 1, 1);
			background.draw(guiGraphics, this.backgroundBounds);
		}
		super.method_48579(guiGraphics, mouseX, mouseY, partialTicks);
	}
}
